@@ -9,13 +9,13 @@ class LogEntry(models.Model):
     creation_time = models.DateTimeField(auto_now_add=True, db_index=True)
     message = models.TextField()
     level_no = models.SmallIntegerField()
-    level_name = models.CharField(max_length=50)
+    level_name = models.CharField(max_length=50, db_index=True)
     func_name = models.CharField(max_length=255)
     module = models.CharField(max_length=255)
     path_name = models.CharField(max_length=255)
     file_name = models.CharField(max_length=255)
     line_no = models.BigIntegerField()
-    name = models.CharField(max_length=255)
+    name = models.CharField(max_length=255, db_index=True)
     process = models.BigIntegerField()
     process_name = models.CharField(max_length=255)
     thread = models.BigIntegerField()
